/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.assertion.sink;

import org.apache.seatunnel.api.configuration.util.OptionMark;
import org.apache.seatunnel.connectors.seatunnel.assertion.rule.AssertCatalogTableRule;

import lombok.Data;

import java.util.List;

@Data
public class Rules {

    @OptionMark(description = "row rules for row validation")
    private List<RowRule> rowRules;

    @OptionMark(description = "field rules for field validation")
    private List<FieldRule> fieldRules;

    @OptionMark(description = "catalog table rule for catalog table validation")
    private AssertCatalogTableRule catalogTableRule;
}
